@@ -6,6 +6,6 @@ from pipda import Symbolic
 # >>> df >> mutate(f.x+1)
 # In such a case, `f.x+1` cannot be fetched, we use `Var0` instead.
 DEFAULT_COLUMN_PREFIX = "_Var"
-NA_PLACEHOLDER = "<NA>"
+NA_REPR = "<NA>"
 
-f = Symbolic() # pylint: disable=invalid-name
+f = Symbolic()  # pylint: disable=invalid-name
