@@ -1,12 +1,14 @@
 """Basic functions"""
 from typing import Any, Iterable
-
 import numpy
+
 from pandas import Series
 from pipda import register_func
 
 from ..core.contexts import Context
 from ..core.collections import Collection
+from ..core.utils import Array
+
 
 @register_func(None, context=Context.EVAL)
 def itemgetter(data: Iterable[Any], *subscripts) -> numpy.ndarray:
@@ -24,8 +26,7 @@ def itemgetter(data: Iterable[Any], *subscripts) -> numpy.ndarray:
         *subscripts: The subscripts
     """
     flattened = Collection(
-        subs.values if isinstance(subs, Series) else subs
-        for subs in  subscripts
+        subs.values if isinstance(subs, Series) else subs for subs in subscripts
     )
 
-    return numpy.array([data[sub] for sub in flattened])
+    return Array([data[sub] for sub in flattened])
